@@ -4,6 +4,8 @@ use App::Ack;
 
 use warnings;
 use strict;
+use overload
+    '""' => 'name';
 
 sub FAIL {
     require Carp;
@@ -27,7 +29,7 @@ If there's a failure, it throws a warning and returns an empty list.
 =cut
 
 sub new {
-    FAIL();
+    return FAIL();
 }
 
 =head2 $res->name()
@@ -37,7 +39,18 @@ Returns the name of the resource.
 =cut
 
 sub name {
-    FAIL();
+    return FAIL();
+}
+
+=head2 $res->basename()
+
+Returns the basename (the last component the path)
+of the resource.
+
+=cut
+
+sub basename {
+    return FAIL();
 }
 
 =head2 $res->is_binary()
@@ -48,9 +61,20 @@ match in the file, then ack will not try to display a match line.
 =cut
 
 sub is_binary {
-    FAIL();
+    return FAIL();
 }
 
+=head2 $res->open()
+
+Opens a filehandle for reading this resource and returns it, or returns
+undef if the operation fails (the error is in C<$!>).  Instead of calling
+C<close $fh>, C<$res-E<gt>close> should be called.
+
+=cut
+
+sub open {
+    return FAIL();
+}
 
 =head2 $res->needs_line_scan( \%opts )
 
@@ -67,7 +91,7 @@ have to do the line-by-line, too.
 =cut
 
 sub needs_line_scan {
-    FAIL();
+    return FAIL();
 }
 
 =head2 $res->reset()
@@ -79,21 +103,7 @@ is true.
 =cut
 
 sub reset {
-    FAIL();
-}
-
-=head2 $res->next_text()
-
-API: Gets the next line of text from the resource.  Returns true
-if there is one, or false if not.
-
-Sets C<$_> with the line of text, and C<$.> for the ID number of
-the text.  This basically emulates a call to C<< <$fh> >>.
-
-=cut
-
-sub next_text {
-    FAIL();
+    return FAIL();
 }
 
 =head2 $res->close()
@@ -103,7 +113,28 @@ API: Close the resource.
 =cut
 
 sub close {
-    FAIL();
+    return FAIL();
+}
+
+=head2 $res->clone
+
+Clones this resource.
+
+=cut
+
+sub clone {
+    return FAIL();
+}
+
+=head2 $res->firstliney
+
+Returns the first line (or first 250 characters, whichever comes first of a
+resource).  Resource subclasses are encouraged to cache this value.
+
+=cut
+
+sub firstliney {
+    return FAIL();
 }
 
 1;
